#-------------------------------------------------------------------------------
# @(#) UMTS-Ericsson-SGSN-R8/admin_files/3-GW/EngineConfig.pm UMTS-Ericsson-SGSN-R8_b1.0.0.4:aset.011947:1:1@(#)
#-------------------------------------------------------------------------------
#
# This perl module contains the configuration information for this parser.
# If you don't understand the format of this configuration file DON'T TOUCH IT.
#
# UMTS Ericsson SGSN R7
# 
# (c) Copyright IBM Corporation 2008. All rights reserved.

package EngineConfig;

@ISA = qw(Exporter);
@EXPORT = qw(engine_config);

#use diagnostics;
use strict;
use Exporter ();

# DDM configuration
use DDM_MANIP_Config;

#-------------------------------------------------------------------------------
  

#-------------------------------------------------------------------------------
# Modify/Add rules here
#-------------------------------------------------------------------------------
my @rules = (
{
    RULE_TYPE => 'XML_3GPP',
    RULE_DESC => '3GPP XML Interface',
    INPUT_FILE_DESCRIPTION => ['^\w{1}\d{8}[.]\d{4}[+-]*\d{0,4}-\d{8}[.]\d{4}[+-]?\d{0,4}_[A-Za-z0-9]+[.].+$'],
    INPUT_DIR_DEPTH => '2',
    FILENAME_HEADER_FIELDS => {
                                  Type => '^([A-D])\d{8}.+$',
                                  EndDate => '^\w{1}(\d{8}).+$',
                                  ## Commented out - does not fit the format of R6 filename
                                  #StartDate      => '^\w{1}(\d{8}).+$',
                                  #StartTime      => '^\w{1}\d{8}\.(\d{4}).+$',
                                  #Node_Id        => '^\w{1}\d{8}\.\d{4}[+-]*\d{0,4}-\d{8}\.\d{4}[+-]?\d{0,4}_(\w{5})_.+$',
                                  GMT_difference => '^\w{1}\d{8}\.\d{4}([+-]?\d{0,4})-.+$',
                                  UniqueID => '^\w{1}\d{8}\.\d{4}[+-]*\d{0,4}-\d{8}\.\d{4}[+-]?\d{0,4}_(\w+).+$',
                                  Node_Id => '^\w{1}\d{8}[.]\d{4}[+-]*\d{0,4}-\d{8}[.]\d{4}[+-]?\d{0,4}_([A-Za-z0-9]+)[.].+$',                                                         
                              },
    DIRECTORY_HEADER_FIELDS            => {
                                                  Network_Id => '\/Network_?([^\/]+)\/?',
		                                  Region_Id    => '\/[^\/]+\/Region_?([^\/]+)\/?',
		                              },
    XML_PIF_HEADER_ELEMENT_NAMES       => ['ffvv-_f.v','sn','st','vn','cbt','nedn','ts'],
    XML_UNIQUE_PIF_BLOCK_HEADER_ELEMENT_NAMES  => ['mts','gp'],
    XML_ENABLE_DTD_VALIDATION          => 1,
    XML_3GPP_FILENAME_VALIDATION       => {
                                                  Type             => '^(A|B|C|D).+$',
                                                  StartDate => '^\w{1}(\d{8}).+$',
                                                  StartTime             => '^\w{1}\d{8}\.(\d{4}).+$',
                                              },
    XML_HEADER_INFO_FOR_PIF_FILENAME   => ['UniqueID','mts_Date','mts_Time'],
    XML_UNIQUE_PIF_BLOCK_ELEMENT_NAME  => 'mi',
    XML_MEASUREMENT_TYPE_ELEMENT_SEQ   => 'mt', 
    XML_MEASUREMENT_VALUE_ELEMENT_NAME => 'mv',
    XML_MEASUREMENT_RESULTS_ELEMENT_SEQ        => 'r',
    XML_OUTPUT_BLOCK_ELEMENT_NAME              => 'mt',
    XML_OUTPUT_BLOCK_DESCRIPTION               => '^([A-Za-z][A-Za-z\.][A-Za-z0-9\.])',
    XML_OBJECT_INSTANCE_ID_ELEMENT_NAME        => 'moid',
    XML_ENABLE_PIF_PER_MOID                    => '0',
    XML_SUSPECT_FLAG_ELEMENT_NAME              => 'sf',
    XML_ALTERNATIVE_COUNTER_NULL_VALUE         => '-9999',
    XML_MAX_COUNTER_NAME_SIZE                  => 50,
    XML_ALTERNATIVE_OUTPUT_BLOCK_NAMES         => {
                                                        'MM\.' => 'MM',
                                                        'SM\.' => 'SM_nonindexed',                                                        
                                                        'SEC' => 'Security',
                                                        'frP' => 'FRPvc',
                                                        'frW' => 'FRWan',
                                                        'ifO' => 'PXM',
                                                        'icm' => 'ICMP',
                                                        'eth' => 'Ethernet',
                                                        'hdl' => 'E1_Link',
                                                        'CAM' => 'CAMEL',
                                                        'ipR' => 'IP',
                                                        'ISY' => 'ISYSC',
                                                        'nsD' => 'NSC_NSVC',
                                                      },                                                      
    XML_ALTERNATIVE_COUNTER_NAMES              => [
                                                        ['\.', '_'],
                                                        ['SEC.AttReqAuthSetsSentToHlrBySGSN','SEC_attReqAuthSetsSentToHlrBySgsn'],
                                                      ],
    XML_ENABLE_PIF_COUNTER_IN_FILENAME         => "True",
    XML_CHARACTER_SUBSTITUTION                 => {
                                                        '"MeasDataCollection.dtd"' => '"./32.104-01.dtd"',
                                                        '"/opt/nortel/config/common/observation/32.401-01.dtd"' => '"./32.104-01.dtd"',
                                                        ' xmlns:HTML=\"http://www\.w3\.org/TR/REC-xml\"' => "",
                                                      },
    XML_DDM_MANIP_RULES                        => ddm_manip_config(),
    HEADER_DATA_RECORD_PROCESSING              => sub {
                                                     my ($blkname_ref, $h_ref, $d_ref) = @_;
                                                         if ( exists($h_ref->{Node_Id}) ) {
                                                             ($d_ref->{Node_Id}) = $h_ref->{Node_Id};
	        	                                                 ($d_ref->{Region_Id}) = $h_ref->{Region_Id};
	        	                                                 ($d_ref->{Network_Id}) = $h_ref->{Network_Id};
	        	                                             }
	        	                                             
	        	                                             if ( exists($h_ref->{mts}) ) {
	        	                                                 ($h_ref->{EndTime}) = $h_ref->{mts} =~ /^\d{2}\w{3}\d{4}_(\d{2}:\d{2}):\d{2}$/;
	        	                                             }
	        	                                             return 0;
	        	                                          },
},

{
    RULE_TYPE                                  => 'XML_3GPP',
    RULE_DESC                                  => '3GPP XML Interface',
    INPUT_FILE_DESCRIPTION                     => ['^\w{1}\d{8}[.]\d{4}[+-]*\d{0,4}-\d{8}[.]\d{4}[+-]?\d{0,4}_[A-Za-z0-9]+_\w+[.].+$'],
    INPUT_DIR_DEPTH                            => '2',
    FILENAME_HEADER_FIELDS                     => {
                                                         Type           => '^([A-D])\d{8}.+$',
                                                         EndDate        => '^\w{1}(\d{8}).+$',
                                                         ## Commented out - does not fit the format of R6 filename
                                                         #StartDate      => '^\w{1}(\d{8}).+$',
                                                         #StartTime      => '^\w{1}\d{8}\.(\d{4}).+$',
                                                         #Node_Id        => '^\w{1}\d{8}\.\d{4}[+-]*\d{0,4}-\d{8}\.\d{4}[+-]?\d{0,4}_(\w{5})_.+$',
                                                         GMT_difference => '^\w{1}\d{8}\.\d{4}([+-]?\d{0,4})-.+$',
                                                         UniqueID       => '^\w{1}\d{8}\.\d{4}[+-]*\d{0,4}-\d{8}\.\d{4}[+-]?\d{0,4}_(\w+).+$',
                                                         Node_Id        => '^\w{1}\d{8}[.]\d{4}[+-]*\d{0,4}-\d{8}[.]\d{4}[+-]?\d{0,4}_([A-Za-z0-9]+)_\w+[.].+$',                                                         
                                                      },
    DIRECTORY_HEADER_FIELDS                    => {
                                                         Network_Id => '\/Network_?([^\/]+)\/?',
		                                	                   Region_Id    => '\/[^\/]+\/Region_?([^\/]+)\/?',
		                                	                },
    XML_PIF_HEADER_ELEMENT_NAMES               => ['ffvv-_f.v','sn','st','vn','cbt','nedn','ts'],
    XML_UNIQUE_PIF_BLOCK_HEADER_ELEMENT_NAMES  => ['mts','gp'],
    XML_ENABLE_DTD_VALIDATION                  => 1,
    XML_3GPP_FILENAME_VALIDATION               => {
                                                        Type             => '^(A|B|C|D).+$',
                                                        StartDate => '^\w{1}(\d{8}).+$',
                                                        StartTime             => '^\w{1}\d{8}\.(\d{4}).+$',
                                                      },
    XML_HEADER_INFO_FOR_PIF_FILENAME           => ['UniqueID','mts_Date','mts_Time'],
    XML_UNIQUE_PIF_BLOCK_ELEMENT_NAME          => 'mi',
    XML_MEASUREMENT_TYPE_ELEMENT_SEQ           => 'mt', 
    XML_MEASUREMENT_VALUE_ELEMENT_NAME         => 'mv',
    XML_MEASUREMENT_RESULTS_ELEMENT_SEQ        => 'r',
    XML_OUTPUT_BLOCK_ELEMENT_NAME              => 'mt',
    XML_OUTPUT_BLOCK_DESCRIPTION               => '^([A-Za-z][A-Za-z\.][A-Za-z0-9\.])',
    XML_OBJECT_INSTANCE_ID_ELEMENT_NAME        => 'moid',
    XML_ENABLE_PIF_PER_MOID                    => '0',
    XML_SUSPECT_FLAG_ELEMENT_NAME              => 'sf',
    XML_ALTERNATIVE_COUNTER_NULL_VALUE         => '-9999',
    XML_MAX_COUNTER_NAME_SIZE                  => 50,
    XML_ALTERNATIVE_OUTPUT_BLOCK_NAMES         => {
                                                        'MM\.' => 'MM',
                                                        'SM\.' => 'SM_nonindexed',                                                        
                                                        'SEC' => 'Security',
                                                        'frP' => 'FRPvc',
                                                        'frW' => 'FRWan',
                                                        'ifO' => 'PXM',
                                                        'icm' => 'ICMP',
                                                        'eth' => 'Ethernet',
                                                        'hdl' => 'E1_Link',
                                                        'CAM' => 'CAMEL',
                                                        'ipR' => 'IP',
                                                        'ISY' => 'ISYSC',                                                        
                                                      },                                                      
    XML_ALTERNATIVE_COUNTER_NAMES              => [
                                                        ['\.', '_'],
                                                        ['SEC.AttReqAuthSetsSentToHlrBySGSN','SEC_attReqAuthSetsSentToHlrBySgsn'],
                                                      ],
    XML_ENABLE_PIF_COUNTER_IN_FILENAME         => "True",
    XML_CHARACTER_SUBSTITUTION                 => {
                                                        '"MeasDataCollection.dtd"' => '"./32.104-01.dtd"',
                                                        '"/opt/nortel/config/common/observation/32.401-01.dtd"' => '"./32.104-01.dtd"',
                                                        ' xmlns:HTML=\"http://www\.w3\.org/TR/REC-xml\"' => "",
                                                      },
    XML_DDM_MANIP_RULES                        => ddm_manip_config(),
    HEADER_DATA_RECORD_PROCESSING              => sub {
                                                         my ($blkname_ref, $h_ref, $d_ref) = @_;
                                                         if ( exists($h_ref->{Node_Id}) ) {
                                                             ($d_ref->{Node_Id}) = $h_ref->{Node_Id};
	        	                                                 ($d_ref->{Region_Id}) = $h_ref->{Region_Id};
	        	                                                 ($d_ref->{Network_Id}) = $h_ref->{Network_Id};
	        	                                             }
	        	                                             
	        	                                             if ( exists($h_ref->{mts}) ) {
	        	                                                 ($h_ref->{EndTime}) = $h_ref->{mts} =~ /^\d{2}\w{3}\d{4}_(\d{2}:\d{2}):\d{2}$/;
	        	                                             }
	        	                                             return 0;
	        	                                          },
},


);

sub engine_config {
        return \@rules;
}

1;
